@@ -53,8 +53,9 @@ from .interfaces import (
     method,             # Decorator for methods
     )
 
-from .protocol import (
+from .zerojson import (
     RemoteComponent,    # Remote component implementation
+    ioloop,             # IOLoop instance for a service
     )
 
 from .nsclient import (
@@ -62,10 +63,6 @@ from .nsclient import (
     nameserver,         # Function to locate nameserver
     )
 
-from .server import (
-    ioloop,             # IOLoop instance for a service
-    )
-
 from .launcher import (
     main,               # Main loop for a service
     )
