@@ -61,6 +61,14 @@ class Request(object):
         self.session = session
         self.args = args
 
+    def response(self, result):  # pylint: disable-msg=R0201
+        """Build response object to return from method.
+
+        *result* is a JSON-serializable entity to return to client.
+
+        """
+        return result
+
 
 class BaseComponent(object):
     """Abstract base class for components."""
@@ -129,28 +137,44 @@ class Session(dict):
         self.session_id = session_id
 
 
-class SessionFactory(object):
-    """Factory responsible for creating sessions for the interface."""
+class Call(dict):
+    """Class representing single remote call.
 
-    __slots__ = ("_sessions", )
+    Inherits from `dict`, provides one additional attribute:
 
-    def __init__(self):
+    .. attribute: call_id
+
+       UUID of call
+
+    """
+
+    def __init__(self, call_id, *args, **kw):
+        """Constructor."""
+        super(Call, self).__init__(*args, **kw)
+        self.call_id = call_id
+
+
+class UUIDFactory(object):
+    """Factory responsible for creating objects with UUID."""
+
+    def __init__(self, items_factory):
         """Initialize empty factory."""
-        self._sessions = {}
+        self._items = {}
+        self._items_factory = items_factory
 
     def new(self):
-        """Create new session object and return it's ID."""
-        sessid = uuid.uuid1().hex
-        self._sessions[sessid] = Session(sessid)
-        return self._sessions[sessid]
+        """Create new session object and return it."""
+        unique_id = uuid.uuid1().hex
+        self._items[unique_id] = self._items_factory(unique_id)
+        return self._items[unique_id]
 
-    def get(self, sessid):
-        """Fetch existing session object by it's ID.
+    def get(self, unique_id):
+        """Fetch existing item by it's ID.
 
         Raises `KeyError` on failure.
 
         """
-        return self._sessions[sessid]
+        return self._items[unique_id]
 
 
 # Private
