@@ -49,12 +49,16 @@ def interface(name):
     return _wrapper
 
 
-def method(name):
+def method(name, body=None):
     """Decorator for method *name*.
 
     Method should take at least one positional argument: *request*,
     which is an object of type :class:`pycom.Request`.
 
+    Method should return either JSON-serializable entity,
+    or result of `request.response()` call
+    (see :meth:`pycom.Request.response`).
+
     Example::
 
         import pycom
@@ -65,12 +69,30 @@ def method(name):
             @pycom.method("method_name")
             def my_method(self, request): print request.args
 
-    """
-    def _wrapper(wrapped):  # pylint: disable-msg=C0111
-        wrapped.__method__ = Method(wrapped, name)
-        return wrapped
+    If *body* is present, this function does not act as a decorator,
+    but directly return appropriate object for
+    :meth:`pycom.interfaces.Interface.register_method`.
+    Here is a useful snippet for adding method in runtime::
 
-    return _wrapper
+        import pycom
+
+        @pycom.interface("com.example.interface.foo")
+        class ClassProvidingInterface(object): pass
+
+        def method_body(self, request): pass
+
+        ClassProvidingInterface.__interface__.register_method(
+            pycom.method("method_name", body=method_body))
+
+    """
+    if body is None:
+        def _wrapper(wrapped):  # pylint: disable-msg=C0111
+            wrapped.__method__ = Method(wrapped, name)
+            return wrapped
+
+        return _wrapper
+    else:
+        return Method(body, name)
 
 
 registry = {}
