@@ -27,12 +27,14 @@
 """Main routine implementation."""
 
 import logging
+import os
+import uuid
 from optparse import OptionParser
 
 from six import iterkeys
 
-from . import base, constants, exceptions, interfaces, nsclient
-from . import server, utils
+from . import base, constants, exceptions, interfaces, nsclient, utils
+from .zerojson import server
 
 
 def main(argv=None):
@@ -66,6 +68,8 @@ def main(argv=None):
             dest="verbosity",
             help="Be as verbose as possible",
             const=logging.DEBUG)
+        parser.add_option("-n", "--nameserver", action="store", dest="ns",
+            help="NameServer address")
         (options, args) = parser.parse_args(args=argv)
 
         address = options.address
@@ -74,19 +78,23 @@ def main(argv=None):
         if not len(args):
             parser.error("Expected at least one positional argument: module")
 
+        if options.ns is not None:
+            base.configure(nameserver=options.ns)
+
         for module_name in args:
             try:
                 __import__(module_name)
             except ImportError:
                 parser.error("Cannot import module " + module_name)
 
-        utils.logger().setLevel(options.verbosity or logging.INFO)
+        utils.logger().setLevel(options.verbosity or
+            int(os.environ.get("PYCOM_LOGGING_LEVEL", 0)) or logging.INFO)
 
     if address is None:
         raise exceptions.ConfigurationError("Set address in the configuration")
 
     if service is None:
-        raise exceptions.ConfigurationError("Set service in the configuration")
+        service = "/auto/" + uuid.uuid4().hex
 
     ns_component = nsclient.nameserver()
     for interface in iterkeys(interfaces.registry):
