@@ -28,7 +28,8 @@
 
 import threading
 
-from . import base, constants, exceptions, interfaces, protocol
+from . import base, constants, exceptions, interfaces
+from .zerojson import client
 
 
 def nameserver():
@@ -53,7 +54,7 @@ def nameserver():
         else:
             raise exceptions.ServiceNotFound("Nameserver not found")
     else:
-        ns_component = protocol.detect_ns(ns_conf)
+        ns_component = client.detect_ns(ns_conf)
 
     _tls.ns_component = ns_component
     return ns_component
@@ -79,7 +80,7 @@ def locate(iface, service_name=None):
         else:
             raise
 
-    return protocol.RemoteComponent(info["address"], iface)
+    return client.RemoteComponent(info["address"], iface)
 
 
 # Private
