@@ -27,8 +27,9 @@
 """Tests for pycom.apps.nameserver."""
 
 import pycom
-from pycom import constants, exceptions, protocol
+from pycom import constants, exceptions
 from pycom.apps import nameserver
+from pycom.zerojson import client as protocol
 
 from .utils import unittest
 
