@@ -24,7 +24,7 @@
 #   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 #   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-"""Tests for pycom.interfaces."""
+"""Tests for pycom.interfaces and pycom.base."""
 
 import functools
 import re
@@ -163,7 +163,7 @@ class HooksTest(BaseTest, unittest.TestCase):
 class LocalComponentTest(BaseTest, unittest.TestCase):
 
     def testCallExisting(self):
-        iface = "test.test_components.LocalComponentTest.testCall"
+        iface = "test.test_components.LocalComponentTest.testCallExisting"
         meth1 = "method1"
         testObject1 = object()
         testObject2 = object()
@@ -181,6 +181,45 @@ class LocalComponentTest(BaseTest, unittest.TestCase):
         self.assertIsInstance(component, pycom.BaseComponent)
         self.assertIs(component.invoke(meth1, args=testObject1), testObject2)
 
+    def testCallWithResponse(self):
+        iface = "test.test_components.LocalComponentTest.testCallWithResponse"
+        meth1 = "method1"
+        testObject1 = object()
+        testObject2 = object()
+
+        @pycom.interface(iface)
+        class InterfaceWithMethods(object):
+
+            @pycom.method(meth1)
+            def m1(self, request):
+                assert self.__interface__.name == iface
+                assert request.args is testObject1
+                return request.response(testObject2)
+
+        component = InterfaceWithMethods().__interface__
+        self.assertIsInstance(component, pycom.BaseComponent)
+        self.assertIs(component.invoke(meth1, args=testObject1), testObject2)
+
+    def testCallAddedInRT(self):
+        iface = "test.test_components.LocalComponentTest.testCallAddedInRT"
+        meth1 = "method1"
+        testObject1 = object()
+        testObject2 = object()
+
+        @pycom.interface(iface)
+        class InterfaceWithMethods(object): pass
+
+        def meth1(self, request):
+            assert request.args is testObject1
+            return request.response(testObject2)
+
+        InterfaceWithMethods.__interface__.register_method(
+            pycom.method(meth1, body=meth1))
+
+        component = InterfaceWithMethods().__interface__
+        self.assertIsInstance(component, pycom.BaseComponent)
+        self.assertIs(component.invoke(meth1, args=testObject1), testObject2)
+
     def testCallNonExisting(self):
         iface = "test.test_components.LocalComponentTest.testCallNonExisting"
         meth1 = "method1"
