@@ -24,19 +24,22 @@
 #   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 #   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-"""Tests for pycom.launcher."""
+"""Tests for pycom.launcher and pycom.zerojson."""
 
 import io
 import random
 import sys
 import threading
 import time
+import uuid
 
+import six
 from six import StringIO
 
 import pycom
 import pycom.apps.nameserver
-from pycom import base, constants, nsclient, protocol, utils
+from pycom import base, constants, nsclient, utils
+from pycom.zerojson import call, client as protocol
 
 from .utils import unittest, Replacer
 from .test_nsclient import BaseTest
@@ -68,16 +71,11 @@ class MainTest(BaseTest, unittest.TestCase):
 
         self._testService(iface, meth, _testMethod, _check, self)
 
-    def testConfigurationError1(self):
+    def testConfigurationError(self):
         pycom.configure(service="/test/test_launcher")
         self.assertRaisesRegexp(pycom.ConfigurationError, "address",
             pycom.main)
 
-    def testConfigurationError2(self):
-        pycom.configure(address="ipc://banana!")
-        self.assertRaisesRegexp(pycom.ConfigurationError, "service",
-            pycom.main)
-
     def testUnknownInterface(self):
         iface = "test.test_launcher.MainTest.testUnknownInterface"
         meth = "test_method"
@@ -149,6 +147,87 @@ class MainTest(BaseTest, unittest.TestCase):
 
         self._testService(iface, meth, _testSession, _check, self)
 
+    def testUnknownCommand(self):
+        iface = "test.test_launcher.MainTest.testUnknownCommand"
+        meth = "test_method"
+
+        def _check(address, self):
+            component = protocol.RemoteComponent(address, iface)
+            with self.assertRaisesRegexp(pycom.RemoteError,
+                    "Unknown command") as context:
+                message = component._send_message(b"banana!", b"{}", 1000)[1]
+                self.assertTrue(message)
+                call.CallCommand().response_from_wire(message)
+            self.assertEqual(context.exception.code,
+                constants.ERROR_BAD_REQUEST)
+
+        self._testService(iface, meth, _testMethod, _check, self)
+
+    def testWrongJSON(self):
+        iface = "test.test_launcher.MainTest.testWrongJSON"
+        meth = "test_method"
+
+        def _check(address, self):
+            component = protocol.RemoteComponent(address, iface)
+            with self.assertRaisesRegexp(pycom.RemoteError,
+                    "Cannot decode response") as context:
+                message = component._send_message(constants.PROTO_CMD_CALL,
+                    b"!!!", 1000)[1]
+                call.CallCommand().response_from_wire(message)
+            self.assertEqual(context.exception.code,
+                constants.ERROR_BAD_REQUEST)
+
+        self._testService(iface, meth, _testMethod, _check, self)
+
+    def testMissingFields(self):
+        iface = "test.test_launcher.MainTest.testMissingFields"
+        meth = "test_method"
+
+        def _check(address, self):
+            component = protocol.RemoteComponent(address, iface)
+            with self.assertRaisesRegexp(pycom.RemoteError,
+                    "Field [a-z]+ is required") as context:
+                message = component._send_message(constants.PROTO_CMD_CALL,
+                    b"{}", 1000)[1]
+                call.CallCommand().response_from_wire(message)
+            self.assertEqual(context.exception.code,
+                constants.ERROR_BAD_REQUEST)
+
+        self._testService(iface, meth, _testMethod, _check, self)
+
+    def testWrongUTF8(self):
+        iface = "test.test_launcher.MainTest.testWrongUTF8"
+        meth = "test_method"
+
+        def _check(address, self):
+            component = protocol.RemoteComponent(address, iface)
+            with self.assertRaisesRegexp(pycom.RemoteError,
+                    "Invalid encoding, expected UTF-8") as context:
+                message = component._send_message(constants.PROTO_CMD_CALL,
+                    b"{\"v1\": \"\xff\xff\"}", 1000)[1]
+                call.CallCommand().response_from_wire(message)
+            self.assertEqual(context.exception.code,
+                constants.ERROR_BAD_REQUEST)
+
+        self._testService(iface, meth, _testMethod, _check, self)
+
+    def testWrongPartsCount(self):
+        iface = "test.test_launcher.MainTest.testWrongPartsCount"
+        meth = "test_method"
+
+        def _check(address, self):
+            component = protocol.RemoteComponent(address, iface)
+            with self.assertRaisesRegexp(pycom.RemoteError,
+                    "Expected two parts, got 3") as context:
+                message = component._send_message(constants.PROTO_CMD_CALL,
+                    call.CallCommand().request_to_wire(iface, meth, {}),
+                    1000, attachment=b"")[1]
+                call.CallCommand().response_from_wire(message)
+            self.assertEqual(context.exception.code,
+                constants.ERROR_BAD_REQUEST)
+
+        self._testService(iface, meth, _testMethod, _check, self)
+
     # Private
 
     def _testService(self, iface, meth, meth_body, call, *args, **kw):
@@ -159,7 +238,7 @@ class MainTest(BaseTest, unittest.TestCase):
             def test_method(self, request):
                 return meth_body(request)
 
-        address = "ipc://pycom/test_launcher-%d" % random.randint(0, 999999)
+        address = "ipc:///tmp/pycom_test_launcher-%d" % uuid.uuid4().int
 
         def _check():
             try:
@@ -172,6 +251,7 @@ class MainTest(BaseTest, unittest.TestCase):
         pycom.configure(address=address, service="/test/test_launcher")
         pycom.main()
 
+
 _testMethod = lambda request: {"input": request.args}
 
 def _testMethodWithKnownError(request):
@@ -207,22 +287,38 @@ class ArgsTest(unittest.TestCase):
         with Replacer(sys, "stderr", StringIO()):
             self.assertRaises(SystemExit, pycom.main, ["sys", "-a"])
 
-    def testFailEmptyService(self):
-        with Replacer(sys, "stderr", StringIO()):
-            self.assertRaises(SystemExit, pycom.main, ["sys", "-s"])
+    def testGeneratedService(self):
+        address = "ipc:///tmp/pycom_test_launcher-%d" % uuid.uuid4().int
+
+        pycom.ioloop().add_callback(pycom.ioloop().stop)
+        pycom.main(["sys", "-a", address])
 
     def testFailUnknownOption(self):
         with Replacer(sys, "stderr", StringIO()):
             self.assertRaises(SystemExit, pycom.main, ["sys", "-x"])
 
     def testCorrectOptions(self):
-        address = "ipc://pycom/test_launcher-%d" % random.randint(0, 999999)
+        address = "ipc:///tmp/pycom_test_launcher-%d" % uuid.uuid4().int
 
         pycom.ioloop().add_callback(pycom.ioloop().stop)
         pycom.main(["sys", "-a", address, "-s", "/test/test_launcher2"])
 
+    def testNameserverOption(self):
+        address = "ipc:///tmp/pycom_test_launcher-%d" % uuid.uuid4().int
+
+        def _check():
+            try:
+                self.assertEqual(base.configuration["nameserver"],
+                    "test_ns_vi_cmd")
+            finally:
+                pycom.ioloop().stop()
+
+        pycom.ioloop().add_callback(_check)
+        pycom.main(["sys", "-a", address, "-s", "/test/test_launcher2",
+            "-n", "test_ns_vi_cmd"])
+
     def testUnknownModule(self):
-        address = "ipc://pycom/test_launcher-%d" % random.randint(0, 999999)
+        address = "ipc:///tmp/pycom_test_launcher-%d" % uuid.uuid4().int
 
         with Replacer(sys, "stderr", StringIO()):
             self.assertRaises(SystemExit, pycom.main,
